summaryrefslogtreecommitdiff
path: root/unotools
diff options
context:
space:
mode:
authorJesús Corrius <jesus@softcatala.org>2012-02-01 14:42:58 +0100
committerJesús Corrius <jesus@softcatala.org>2012-02-01 14:43:37 +0100
commit7be0cc289d9745e0842c4fa6c0a6ac3450f3801b (patch)
tree5b349b17cc872dfb45ef5ec73a6ba2eec27a37ef /unotools
parente8b7f1faaf3b0fd837a236a4a53d0f7392723713 (diff)
A few safe replacements of pathes->paths
Diffstat (limited to 'unotools')
-rw-r--r--unotools/inc/unotools/configitem.hxx2
-rw-r--r--unotools/inc/unotools/configpathes.hxx6
-rw-r--r--unotools/inc/unotools/pathoptions.hxx4
-rw-r--r--unotools/source/config/configitem.cxx4
-rw-r--r--unotools/source/config/configpathes.cxx4
-rw-r--r--unotools/source/config/defaultoptions.cxx4
-rw-r--r--unotools/source/config/moduleoptions.cxx4
-rw-r--r--unotools/source/config/pathoptions.cxx4
8 files changed, 16 insertions, 16 deletions
diff --git a/unotools/inc/unotools/configitem.hxx b/unotools/inc/unotools/configitem.hxx
index 7910b68af5dd..fe6f437cc6c1 100644
--- a/unotools/inc/unotools/configitem.hxx
+++ b/unotools/inc/unotools/configitem.hxx
@@ -63,7 +63,7 @@ namespace utl
{
CONFIG_NAME_PLAINTEXT_NAME, // unescaped local node name, for user display etc.
CONFIG_NAME_LOCAL_NAME, // local node name, for use in XNameAccess etc. ("Item", "Q & A")
- CONFIG_NAME_LOCAL_PATH, // one-level relative path, for use when building pathes etc. ("Item", "Typ['Q &amp; A']")
+ CONFIG_NAME_LOCAL_PATH, // one-level relative path, for use when building paths etc. ("Item", "Typ['Q &amp; A']")
CONFIG_NAME_FULL_PATH, // full absolute path. ("/org.openoffice.Sample/Group/Item", "/org.openoffice.Sample/Set/Typ['Q &amp; A']")
CONFIG_NAME_DEFAULT = CONFIG_NAME_LOCAL_PATH // default format
diff --git a/unotools/inc/unotools/configpathes.hxx b/unotools/inc/unotools/configpathes.hxx
index 30a0845e3541..258ea01c97ec 100644
--- a/unotools/inc/unotools/configpathes.hxx
+++ b/unotools/inc/unotools/configpathes.hxx
@@ -95,7 +95,7 @@ namespace utl
@param _sNestedPath
A configuration path that maybe points to a descendant of the node
- identified by <var>_sPrefixPath</var>, with both pathes starting
+ identified by <var>_sPrefixPath</var>, with both paths starting
from the same node (or both being absolute).
@param _sPrefixPath
@@ -108,7 +108,7 @@ namespace utl
@returns
<TRUE/>, if <var>_sPrefixPath</var> is a prefix of <var>_sNestedPath</var>;
<FALSE/> otherwise.<BR/>
- If both pathes are equal <TRUE/> is returned.
+ If both paths are equal <TRUE/> is returned.
*/
sal_Bool isPrefixOfConfigurationPath(::rtl::OUString const& _sNestedPath,
@@ -119,7 +119,7 @@ namespace utl
@param _sNestedPath
A configuration path that points to a descendant of the node
- identified by <var>_sPrefixPath</var>, with both pathes starting
+ identified by <var>_sPrefixPath</var>, with both paths starting
from the same node (or both being absolute).
@param _sPrefixPath
diff --git a/unotools/inc/unotools/pathoptions.hxx b/unotools/inc/unotools/pathoptions.hxx
index 90291368dd95..2ed11788652a 100644
--- a/unotools/inc/unotools/pathoptions.hxx
+++ b/unotools/inc/unotools/pathoptions.hxx
@@ -76,7 +76,7 @@ public:
SvtPathOptions();
virtual ~SvtPathOptions();
- // get the pathes, not const because of using a mutex
+ // get the paths, not const because of using a mutex
const String& GetAddinPath() const;
const String& GetAutoCorrectPath() const;
const String& GetAutoTextPath() const;
@@ -102,7 +102,7 @@ public:
const String& GetUIConfigPath() const;
const String& GetFingerprintPath() const;
- // set the pathes
+ // set the paths
void SetAddinPath( const String& rPath );
void SetAutoCorrectPath( const String& rPath );
void SetAutoTextPath( const String& rPath );
diff --git a/unotools/source/config/defaultoptions.cxx b/unotools/source/config/defaultoptions.cxx
index e37106fa6f41..cb68c88e225d 100644
--- a/unotools/source/config/defaultoptions.cxx
+++ b/unotools/source/config/defaultoptions.cxx
@@ -248,7 +248,7 @@ SvtDefaultOptions_Impl::SvtDefaultOptions_Impl() : ConfigItem( ASCII_STR("Office
{
case ::com::sun::star::uno::TypeClass_STRING :
{
- // multi pathes
+ // multi paths
if ( pValues[nProp] >>= aTempStr )
aFullPath = aPathOpt.SubstituteVariable( aTempStr );
else
@@ -260,7 +260,7 @@ SvtDefaultOptions_Impl::SvtDefaultOptions_Impl() : ConfigItem( ASCII_STR("Office
case ::com::sun::star::uno::TypeClass_SEQUENCE :
{
- // single pathes
+ // single paths
aFullPath = OUString();
Sequence < OUString > aList;
if ( pValues[nProp] >>= aList )
diff --git a/unotools/source/config/moduleoptions.cxx b/unotools/source/config/moduleoptions.cxx
index c66bbff292d4..aa2f076e8572 100644
--- a/unotools/source/config/moduleoptions.cxx
+++ b/unotools/source/config/moduleoptions.cxx
@@ -144,7 +144,7 @@ struct FactoryInfo
//---------------------------------------------------------------------------------------------------------
// returns list of properties, which has changed only!
- // We use given value of sNodeBase to build full qualified pathes ...
+ // We use given value of sNodeBase to build full qualified paths ...
// Last sign of it must be "/". Beacuse we use it directly, without any additional things!
css::uno::Sequence< css::beans::PropertyValue > getChangedProperties( const ::rtl::OUString& sNodeBase )
{
@@ -926,7 +926,7 @@ sal_Bool SvtModuleOptions_Impl::ClassifyFactoryByName( const ::rtl::OUString& sN
*//*-*************************************************************************************************************/
void SvtModuleOptions_Impl::impl_Read( const css::uno::Sequence< ::rtl::OUString >& lFactories )
{
- // Expand every set node name in lFactories to full qualified pathes to his properties
+ // Expand every set node name in lFactories to full qualified paths to his properties
// and get right values from configuration.
const css::uno::Sequence< ::rtl::OUString > lProperties = impl_ExpandSetNames( lFactories );
const css::uno::Sequence< css::uno::Any > lValues = GetProperties( lProperties );
diff --git a/unotools/source/config/pathoptions.cxx b/unotools/source/config/pathoptions.cxx
index 65300ba4ee40..f743bf74549d 100644
--- a/unotools/source/config/pathoptions.cxx
+++ b/unotools/source/config/pathoptions.cxx
@@ -129,7 +129,7 @@ class SvtPathOptions_Impl
public:
SvtPathOptions_Impl();
- // get the pathes, not const because of using a mutex
+ // get the paths, not const because of using a mutex
const String& GetPath( SvtPathOptions::Pathes );
const String& GetAddinPath() { return GetPath( SvtPathOptions::PATH_ADDIN ); }
const String& GetAutoCorrectPath() { return GetPath( SvtPathOptions::PATH_AUTOCORRECT ); }
@@ -156,7 +156,7 @@ class SvtPathOptions_Impl
const String& GetUIConfigPath() { return GetPath( SvtPathOptions::PATH_UICONFIG ); }
const String& GetFingerprintPath() { return GetPath( SvtPathOptions::PATH_FINGERPRINT ); }
- // set the pathes
+ // set the paths
void SetPath( SvtPathOptions::Pathes, const String& rNewPath );
void SetAddinPath( const String& rPath ) { SetPath( SvtPathOptions::PATH_ADDIN, rPath ); }
void SetAutoCorrectPath( const String& rPath ) { SetPath( SvtPathOptions::PATH_AUTOCORRECT, rPath ); }
diff --git a/unotools/source/config/configitem.cxx b/unotools/source/config/configitem.cxx
index eb31e9cec97f..615eb03a777a 100644
--- a/unotools/source/config/configitem.cxx
+++ b/unotools/source/config/configitem.cxx
@@ -678,8 +678,8 @@ void lcl_normalizeLocalNames(Sequence< OUString >& _rNames, ConfigNameFormat _eF
break;
}
}
- OSL_FAIL("Cannot create absolute pathes: missing interface");
- // make local pathes instaed
+ OSL_FAIL("Cannot create absolute paths: missing interface");
+ // make local paths instaed
case CONFIG_NAME_LOCAL_PATH:
{
diff --git a/unotools/source/config/configpathes.cxx b/unotools/source/config/configpathes.cxx
index 6a583ba92d63..8973e63cc8f5 100644
--- a/unotools/source/config/configpathes.cxx
+++ b/unotools/source/config/configpathes.cxx
@@ -124,7 +124,7 @@ sal_Bool splitLastFromConfigurationPath(OUString const& _sInPath,
{
nPos = _sInPath.lastIndexOf('/',nPos);
}
- else // defined behavior for invalid pathes
+ else // defined behavior for invalid paths
{
nStart = 0, nEnd = _sInPath.getLength();
nPos = -1;
@@ -205,7 +205,7 @@ sal_Int32 lcl_findPrefixEnd(OUString const& _sNestedPath, OUString const& _sPref
sal_Int32 nPrefixLength = _sPrefixPath.getLength();
OSL_ENSURE(nPrefixLength == 0 || _sPrefixPath[nPrefixLength-1] != '/',
- "Cannot handle slash-terminated prefix pathes");
+ "Cannot handle slash-terminated prefix paths");
sal_Bool bIsPrefix;
if (_sNestedPath.getLength() > nPrefixLength)